Index: src/arm64/code-stubs-arm64.h |
diff --git a/src/arm64/code-stubs-arm64.h b/src/arm64/code-stubs-arm64.h |
index 88936dd2d23983b7060a20ce89ba2d2eecb1e095..c2e15e097f74f4f9caba91de25affc7f12bce32e 100644 |
--- a/src/arm64/code-stubs-arm64.h |
+++ b/src/arm64/code-stubs-arm64.h |
@@ -14,23 +14,22 @@ void ArrayNativeCode(MacroAssembler* masm, Label* call_generic_code); |
class StringHelper : public AllStatic { |
public: |
- // Compares two flat ASCII strings and returns result in x0. |
- static void GenerateCompareFlatAsciiStrings( |
+ // Compares two flat one-byte strings and returns result in x0. |
+ static void GenerateCompareFlatOneByteStrings( |
MacroAssembler* masm, Register left, Register right, Register scratch1, |
Register scratch2, Register scratch3, Register scratch4); |
- // Compare two flat ASCII strings for equality and returns result in x0. |
- static void GenerateFlatAsciiStringEquals(MacroAssembler* masm, Register left, |
- Register right, Register scratch1, |
- Register scratch2, |
- Register scratch3); |
+ // Compare two flat one-byte strings for equality and returns result in x0. |
+ static void GenerateFlatOneByteStringEquals(MacroAssembler* masm, |
+ Register left, Register right, |
+ Register scratch1, |
+ Register scratch2, |
+ Register scratch3); |
private: |
- static void GenerateAsciiCharsCompareLoop(MacroAssembler* masm, Register left, |
- Register right, Register length, |
- Register scratch1, |
- Register scratch2, |
- Label* chars_not_equal); |
+ static void GenerateOneByteCharsCompareLoop( |
+ MacroAssembler* masm, Register left, Register right, Register length, |
+ Register scratch1, Register scratch2, Label* chars_not_equal); |
DISALLOW_IMPLICIT_CONSTRUCTORS(StringHelper); |
}; |